Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch Merge the nathanw_sa branch.



details:   https://anonhg.NetBSD.org/src/rev/72fd7ac9ced7
branches:  trunk
changeset: 541729:72fd7ac9ced7
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Fri Jan 17 22:58:53 2003 +0000

description:
Merge the nathanw_sa branch.

diffstat:

 sys/arch/hpcmips/hpcmips/machdep.c               |   14 +-
 sys/arch/hpcmips/vr/vr_idle.S                    |    4 +-
 sys/arch/i386/i386/autoconf.c                    |    6 +-
 sys/arch/i386/i386/compat_13_machdep.c           |   14 +-
 sys/arch/i386/i386/cpu.c                         |    6 +-
 sys/arch/i386/i386/db_trace.c                    |   10 +-
 sys/arch/i386/i386/freebsd_machdep.c             |   30 +-
 sys/arch/i386/i386/freebsd_syscall.c             |   37 +-
 sys/arch/i386/i386/genassym.cf                   |   29 +-
 sys/arch/i386/i386/ibcs2_machdep.c               |   27 +-
 sys/arch/i386/i386/ibcs2_syscall.c               |   37 +-
 sys/arch/i386/i386/linux_syscall.c               |   37 +-
 sys/arch/i386/i386/linux_trap.c                  |   11 +-
 sys/arch/i386/i386/locore.S                      |  192 +++++---
 sys/arch/i386/i386/mach_machdep.c                |    7 +-
 sys/arch/i386/i386/mach_sigcode.S                |   10 +-
 sys/arch/i386/i386/mach_syscall.c                |    8 +-
 sys/arch/i386/i386/machdep.c                     |  271 ++++++++++-
 sys/arch/i386/i386/math_emulate.c                |   16 +-
 sys/arch/i386/i386/mem.c                         |    6 +-
 sys/arch/i386/i386/pmap.c                        |   34 +-
 sys/arch/i386/i386/pmc.c                         |   10 +-
 sys/arch/i386/i386/process_machdep.c             |  116 ++--
 sys/arch/i386/i386/procfs_machdep.c              |   12 +-
 sys/arch/i386/i386/spl.S                         |    6 +-
 sys/arch/i386/i386/svr4_machdep.c                |   57 +-
 sys/arch/i386/i386/svr4_sigcode.S                |    6 +-
 sys/arch/i386/i386/svr4_syscall.c                |   39 +-
 sys/arch/i386/i386/sys_machdep.c                 |   80 +-
 sys/arch/i386/i386/syscall.c                     |   66 +-
 sys/arch/i386/i386/trap.c                        |  122 +++-
 sys/arch/i386/i386/vector.S                      |    6 +-
 sys/arch/i386/i386/vm86.c                        |   69 +-
 sys/arch/i386/i386/vm_machdep.c                  |  125 +++--
 sys/arch/i386/include/Makefile                   |    4 +-
 sys/arch/i386/include/cpu.h                      |   35 +-
 sys/arch/i386/include/frame.h                    |   15 +-
 sys/arch/i386/include/frameasm.h                 |   11 +-
 sys/arch/i386/include/ibcs2_machdep.h            |    6 +-
 sys/arch/i386/include/mcontext.h                 |  110 ++++
 sys/arch/i386/include/pmap.h                     |    8 +-
 sys/arch/i386/include/pmc.h                      |    8 +-
 sys/arch/i386/include/proc.h                     |   21 +-
 sys/arch/i386/include/psl.h                      |    3 +-
 sys/arch/i386/include/ptrace.h                   |    6 +-
 sys/arch/i386/include/signal.h                   |   53 ++-
 sys/arch/i386/include/userret.h                  |   22 +-
 sys/arch/i386/include/vm86.h                     |   70 +-
 sys/arch/i386/isa/npx.c                          |  113 ++--
 sys/arch/luna68k/include/Makefile                |    4 +-
 sys/arch/luna68k/include/cpu.h                   |    7 +-
 sys/arch/luna68k/include/mcontext.h              |    3 +
 sys/arch/luna68k/luna68k/genassym.cf             |   38 +-
 sys/arch/luna68k/luna68k/locore.s                |  247 +----------
 sys/arch/luna68k/luna68k/machdep.c               |   24 +-
 sys/arch/luna68k/luna68k/trap.c                  |   83 +-
 sys/arch/m68k/conf/files.m68k                    |    4 +-
 sys/arch/m68k/include/Makefile                   |    4 +-
 sys/arch/m68k/include/frame.h                    |   10 +-
 sys/arch/m68k/include/lock.h                     |    5 +-
 sys/arch/m68k/include/mcontext.h                 |  105 ++++
 sys/arch/m68k/include/proc.h                     |   28 +-
 sys/arch/m68k/include/reg.h                      |    8 +-
 sys/arch/m68k/include/saframe.h                  |   53 ++
 sys/arch/m68k/include/signal.h                   |  106 ++++-
 sys/arch/m68k/include/types.h                    |    3 +-
 sys/arch/m68k/m68k/compat_13_machdep.c           |   10 +-
 sys/arch/m68k/m68k/db_trace.c                    |    9 +-
 sys/arch/m68k/m68k/linux_syscall.c               |   20 +-
 sys/arch/m68k/m68k/linux_trap.c                  |    6 +-
 sys/arch/m68k/m68k/m68k_syscall.c                |   92 ++-
 sys/arch/m68k/m68k/pmap_motorola.c               |   20 +-
 sys/arch/m68k/m68k/proc_subr.s                   |   38 +-
 sys/arch/m68k/m68k/process_machdep.c             |   54 +-
 sys/arch/m68k/m68k/regdump.c                     |    7 +-
 sys/arch/m68k/m68k/sig_machdep.c                 |  270 +++++++++++-
 sys/arch/m68k/m68k/sunos_machdep.c               |   17 +-
 sys/arch/m68k/m68k/sunos_syscall.c               |   38 +-
 sys/arch/m68k/m68k/svr4_machdep.c                |   37 +-
 sys/arch/m68k/m68k/svr4_syscall.c                |    2 +-
 sys/arch/m68k/m68k/switch_subr.s                 |  535 +++++++++++++++++++++++
 sys/arch/m68k/m68k/sys_machdep.c                 |    7 +-
 sys/arch/m68k/m68k/vm_machdep.c                  |   78 ++-
 sys/arch/mac68k/include/Makefile                 |    4 +-
 sys/arch/mac68k/include/cpu.h                    |    8 +-
 sys/arch/mac68k/include/mcontext.h               |    3 +
 sys/arch/mac68k/mac68k/clock.c                   |    5 +-
 sys/arch/mac68k/mac68k/genassym.cf               |   40 +-
 sys/arch/mac68k/mac68k/locore.s                  |  239 +---------
 sys/arch/mac68k/mac68k/machdep.c                 |   22 +-
 sys/arch/mac68k/mac68k/trap.c                    |   82 +-
 sys/arch/macppc/include/Makefile                 |    4 +-
 sys/arch/macppc/include/mcontext.h               |    3 +
 sys/arch/macppc/macppc/machdep.c                 |   25 +-
 sys/arch/mips/include/Makefile                   |    6 +-
 sys/arch/mips/include/cpu.h                      |   11 +-
 sys/arch/mips/include/ecoff_machdep.h            |    4 +-
 sys/arch/mips/include/frame.h                    |   73 +++
 sys/arch/mips/include/mcontext.h                 |  145 ++++++
 sys/arch/mips/include/proc.h                     |   16 +-
 sys/arch/mips/include/signal.h                   |   47 +-
 sys/arch/mips/include/userret.h                  |   20 +-
 sys/arch/mips/mips/bus_dma.c                     |    7 +-
 sys/arch/mips/mips/compat_13_machdep.c           |   14 +-
 sys/arch/mips/mips/cpu_exec.c                    |    8 +-
 sys/arch/mips/mips/db_interface.c                |    8 +-
 sys/arch/mips/mips/db_trace.c                    |    8 +-
 sys/arch/mips/mips/fp.S                          |   10 +-
 sys/arch/mips/mips/genassym.cf                   |   29 +-
 sys/arch/mips/mips/kgdb_machdep.c                |    3 +-
 sys/arch/mips/mips/linux_trap.c                  |    6 +-
 sys/arch/mips/mips/locore.S                      |  288 +++++++++--
 sys/arch/mips/mips/locore_mips1.S                |   31 +-
 sys/arch/mips/mips/locore_mips3.S                |    4 +-
 sys/arch/mips/mips/mipsX_subr.S                  |   32 +-
 sys/arch/mips/mips/mips_emul.c                   |   20 +-
 sys/arch/mips/mips/mips_machdep.c                |  189 +++++++-
 sys/arch/mips/mips/pmap.c                        |   33 +-
 sys/arch/mips/mips/process_machdep.c             |   50 +-
 sys/arch/mips/mips/procfs_machdep.c              |    2 +-
 sys/arch/mips/mips/sig_machdep.c                 |   39 +-
 sys/arch/mips/mips/svr4_machdep.c                |    3 +-
 sys/arch/mips/mips/sys_machdep.c                 |    9 +-
 sys/arch/mips/mips/syscall.c                     |   34 +-
 sys/arch/mips/mips/trap.c                        |  108 ++--
 sys/arch/mips/mips/vm_machdep.c                  |   99 ++-
 sys/arch/mipsco/include/Makefile                 |    4 +-
 sys/arch/mipsco/include/mcontext.h               |    3 +
 sys/arch/mipsco/mipsco/machdep.c                 |   13 +-
 sys/arch/mmeye/include/Makefile                  |    4 +-
 sys/arch/mmeye/include/mcontext.h                |    3 +
 sys/arch/mmeye/mmeye/machdep.c                   |    4 +-
 sys/arch/mvme68k/include/Makefile                |    4 +-
 sys/arch/mvme68k/include/cpu.h                   |    7 +-
 sys/arch/mvme68k/include/mcontext.h              |    3 +
 sys/arch/mvme68k/mvme68k/genassym.cf             |   36 +-
 sys/arch/mvme68k/mvme68k/locore.s                |  288 +-----------
 sys/arch/mvme68k/mvme68k/machdep.c               |   25 +-
 sys/arch/mvme68k/mvme68k/trap.c                  |   84 ++-
 sys/arch/mvmeppc/include/Makefile                |    4 +-
 sys/arch/mvmeppc/include/mcontext.h              |    3 +
 sys/arch/mvmeppc/mvmeppc/machdep.c               |    3 +-
 sys/arch/netwinder/include/Makefile              |    4 +-
 sys/arch/netwinder/include/mcontext.h            |    3 +
 sys/arch/netwinder/netwinder/netwinder_machdep.c |    4 +-
 145 files changed, 4045 insertions(+), 2222 deletions(-)

diffs (truncated from 13017 to 300 lines):

diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/i386/i386/autoconf.c
--- a/sys/arch/i386/i386/autoconf.c     Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/i386/i386/autoconf.c     Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: autoconf.c,v 1.65 2002/11/22 15:23:38 fvdl Exp $       */
+/*     $NetBSD: autoconf.c,v 1.66 2003/01/17 23:10:29 thorpej Exp $    */
 
 /*-
  * Copyright (c) 1990 The Regents of the University of California.
@@ -48,7 +48,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.65 2002/11/22 15:23:38 fvdl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.66 2003/01/17 23:10:29 thorpej Exp $");
 
 #include "opt_compat_oldboot.h"
 
@@ -148,7 +148,7 @@
        ioapic_enable();
 #endif
        /* resync cr0 after FPU configuration */
-       proc0.p_addr->u_pcb.pcb_cr0 = rcr0();
+       lwp0.l_addr->u_pcb.pcb_cr0 = rcr0();
 #ifdef MULTIPROCESSOR
        /* propagate this to the idle pcb's. */
        cpu_init_idle_pcbs();
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/i386/i386/compat_13_machdep.c
--- a/sys/arch/i386/i386/compat_13_machdep.c    Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/i386/i386/compat_13_machdep.c    Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: compat_13_machdep.c,v 1.9 2002/10/01 12:56:48 fvdl Exp $       */
+/*     $NetBSD: compat_13_machdep.c,v 1.10 2003/01/17 23:10:30 thorpej Exp $   */
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2000 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: compat_13_machdep.c,v 1.9 2002/10/01 12:56:48 fvdl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: compat_13_machdep.c,v 1.10 2003/01/17 23:10:30 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -46,6 +46,7 @@
 #include <sys/proc.h>
 #include <sys/user.h>
 #include <sys/mount.h>
+#include <sys/sa.h>
 #include <sys/syscallargs.h>
 
 #ifdef VM86
@@ -53,14 +54,15 @@
 #endif
 
 int
-compat_13_sys_sigreturn(p, v, retval)
-       struct proc *p;
+compat_13_sys_sigreturn(l, v, retval)
+       struct lwp *l;
        void *v;
        register_t *retval;
 {
        struct compat_13_sys_sigreturn_args /* {
                syscallarg(struct sigcontext13 *) sigcntxp;
        } */ *uap = v;
+       struct proc *p = l->l_proc;
        struct sigcontext13 *scp, context;
        struct trapframe *tf;
        sigset_t mask;
@@ -75,7 +77,7 @@
                return (EFAULT);
 
        /* Restore register context. */
-       tf = p->p_md.md_regs;
+       tf = l->l_md.md_regs;
 #ifdef VM86
        if (context.sc_eflags & PSL_VM) {
                void syscall_vm86 __P((struct trapframe));
@@ -84,7 +86,7 @@
                tf->tf_vm86_fs = context.sc_fs;
                tf->tf_vm86_es = context.sc_es;
                tf->tf_vm86_ds = context.sc_ds;
-               set_vflags(p, context.sc_eflags);
+               set_vflags(l, context.sc_eflags);
                p->p_md.md_syscall = syscall_vm86;
        } else
 #endif
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/i386/i386/cpu.c
--- a/sys/arch/i386/i386/cpu.c  Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/i386/i386/cpu.c  Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: cpu.c,v 1.8 2003/01/07 18:54:08 fvdl Exp $ */
+/* $NetBSD: cpu.c,v 1.9 2003/01/17 23:10:30 thorpej Exp $ */
 
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -637,8 +637,8 @@
                    ci->ci_dev == NULL ? "BOOT" : ci->ci_dev->dv_xname,
                    ci->ci_cpuid,
                    ci->ci_flags, ci->ci_ipis,
-                   ci->ci_curproc,
-                   ci->ci_fpcurproc);
+                   ci->ci_curlwp,
+                   ci->ci_fpcurlwp);
        }
 }
 #endif
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/i386/i386/db_trace.c
--- a/sys/arch/i386/i386/db_trace.c     Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/i386/i386/db_trace.c     Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: db_trace.c,v 1.35 2002/11/22 15:23:39 fvdl Exp $       */
+/*     $NetBSD: db_trace.c,v 1.36 2003/01/17 23:10:30 thorpej Exp $    */
 
 /* 
  * Mach Operating System
@@ -27,7 +27,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: db_trace.c,v 1.35 2002/11/22 15:23:39 fvdl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: db_trace.c,v 1.36 2003/01/17 23:10:30 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -387,17 +387,19 @@
                if (trace_thread) {
                        struct proc *p;
                        struct user *u;
+                       struct lwp *l;
                        (*pr)("trace: pid %d ", (int)addr);
                        p = pfind(addr);
                        if (p == NULL) {
                                (*pr)("not found\n");
                                return;
                        }       
-                       if (!(p->p_flag&P_INMEM)) {
+                       l = proc_representative_lwp(p); /* XXX NJWLWP */
+                       if (!(l->l_flag & L_INMEM)) {
                                (*pr)("swapped out\n");
                                return;
                        }
-                       u = p->p_addr;
+                       u = l->l_addr;
                        frame = (int *)u->u_pcb.pcb_ebp;
                        (*pr)("at %p\n", frame);
                } else
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/i386/i386/freebsd_machdep.c
--- a/sys/arch/i386/i386/freebsd_machdep.c      Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/i386/i386/freebsd_machdep.c      Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: freebsd_machdep.c,v 1.35 2002/10/01 12:56:50 fvdl Exp $        */
+/*     $NetBSD: freebsd_machdep.c,v 1.36 2003/01/17 23:10:30 thorpej Exp $     */
 
 /*-
  * Copyright (c) 1998, 2000 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: freebsd_machdep.c,v 1.35 2002/10/01 12:56:50 fvdl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: freebsd_machdep.c,v 1.36 2003/01/17 23:10:30 thorpej Exp $");
 
 #if defined(_KERNEL_OPT)
 #include "opt_vm86.h"
@@ -63,14 +63,14 @@
 #include <compat/freebsd/freebsd_ptrace.h>
 
 void
-freebsd_setregs(p, epp, stack)
-       struct proc *p;
+freebsd_setregs(l, epp, stack)
+       struct lwp *l;
        struct exec_package *epp;
        u_long stack;
 {
-       register struct pcb *pcb = &p->p_addr->u_pcb;
+       register struct pcb *pcb = &l->l_addr->u_pcb;
 
-       setregs(p, epp, stack);
+       setregs(l, epp, stack);
        if (i386_use_fxsave)
                pcb->pcb_savefpu.sv_xmm.sv_env.en_cw = __FreeBSD_NPXCW__;
        else
@@ -97,13 +97,14 @@
        sigset_t *mask;
        u_long code;
 {
-       register struct proc *p = curproc;
+       struct lwp *l = curlwp;
+       register struct proc *p = l->l_proc;
        register struct trapframe *tf;
        struct freebsd_sigframe *fp, frame;
        int onstack;
        sig_t catcher = SIGACTION(p, sig).sa_handler;
 
-       tf = p->p_md.md_regs;
+       tf = l->l_md.md_regs;
 
        /* Do we need to jump onto the signal stack? */
        onstack =
@@ -132,7 +133,7 @@
                frame.sf_sc.sc_fs = tf->tf_vm86_fs;
                frame.sf_sc.sc_es = tf->tf_vm86_es;
                frame.sf_sc.sc_ds = tf->tf_vm86_ds;
-               frame.sf_sc.sc_efl = get_vflags(p);
+               frame.sf_sc.sc_efl = get_vflags(l);
                (*p->p_emul->e_syscall_intern)(p);
        } else
 #endif
@@ -168,7 +169,7 @@
                 * Process has trashed its stack; give it an illegal
                 * instruction to halt it in its tracks.
                 */
-               sigexit(p, SIGILL);
+               sigexit(l, SIGILL);
                /* NOTREACHED */
        }
 
@@ -201,14 +202,15 @@
  * a machine fault.
  */
 int
-freebsd_sys_sigreturn(p, v, retval)
-       struct proc *p;
+freebsd_sys_sigreturn(l, v, retval)
+       struct lwp *l;
        void *v;
        register_t *retval;
 {
        struct freebsd_sys_sigreturn_args /* {
                syscallarg(struct freebsd_sigcontext *) scp;
        } */ *uap = v;
+       struct proc *p = l->l_proc;
        struct freebsd_sigcontext *scp, context;



Home | Main Index | Thread Index | Old Index
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/hpcmips/hpcmips/machdep.c
--- a/sys/arch/hpcmips/hpcmips/machdep.c        Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/hpcmips/hpcmips/machdep.c        Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.78 2002/08/25 20:21:37 thorpej Exp $     */
+/*     $NetBSD: machdep.c,v 1.79 2003/01/17 22:58:53 thorpej Exp $     */
 
 /*-
  * Copyright (c) 1999 Shin Takemura, All rights reserved.
@@ -73,7 +73,7 @@
  */
 
 #include <sys/cdefs.h>                 /* RCS ID & Copyright macro defns */
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.78 2002/08/25 20:21:37 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.79 2003/01/17 22:58:53 thorpej Exp $");
 
 #include "opt_vr41xx.h"
 #include "opt_tx39xx.h"
@@ -412,13 +412,13 @@
                ddb_init(symbolsz, &end, esym);
 #endif /* DDB */
        /*
         * Alloc u pages for proc0 stealing KSEG0 memory.
         */
-       proc0.p_addr = proc0paddr = (struct user *)kernend;
-       proc0.p_md.md_regs =
+       lwp0.l_addr = proc0paddr = (struct user *)kernend;
+       lwp0.l_md.md_regs =
            (struct frame *)((caddr_t)kernend + UPAGES * PAGE_SIZE) - 1;
        memset(kernend, 0, UPAGES * PAGE_SIZE);
-       curpcb = &proc0.p_addr->u_pcb;
+       curpcb = &lwp0.l_addr->u_pcb;
        curpcb->pcb_context[11] = MIPS_INT_MASK | MIPS_SR_INT_IE; /* SR */
 
        kernend += UPAGES * PAGE_SIZE;
@@ -625,7 +625,7 @@
 {
 
        /* take a snap shot before clobbering any registers */
-       if (curproc)
+       if (curlwp)
                savectx((struct user *)curpcb);
 
 #ifdef DEBUG
@@ -412,13 +412,13 @@
 #endif /* DDB */
        /*
-        * Alloc u pages for proc0 stealing KSEG0 memory.
+        * Alloc u pages for lwp0 stealing KSEG0 memory.
         */
diff -r 7bba7d580e47 -r 72fd7ac9ced7 sys/arch/hpcmips/vr/vr_idle.S
--- a/sys/arch/hpcmips/vr/vr_idle.S     Fri Jan 17 22:58:52 2003 +0000
+++ b/sys/arch/hpcmips/vr/vr_idle.S     Fri Jan 17 22:58:53 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: vr_idle.S,v 1.6 2000/08/20 21:50:08 thorpej Exp $      */
+/*     $NetBSD: vr_idle.S,v 1.7 2003/01/17 22:58:53 thorpej Exp $      */
 
 /*
  * Copyright (c) 1992, 1993
@@ -65,7 +65,7 @@
        li      t0, (MIPS_INT_MASK | MIPS_SR_INT_IE)
        mtc0    t0, MIPS_COP_0_STATUS           # enable all interrupts
        nop
-       sw      zero, _C_LABEL(curproc)         # set curproc NULL for stats
+       sw      zero, _C_LABEL(curlwp)          # set curlwp NULL for stats
 #if defined(LOCKDEBUG)
        jal     _C_LABEL(sched_unlock_idle)     # release sched_lock
        nop